==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/nullcheck/RefIntPair.h <==
// public class soot.jimple.toolkits.annotation.nullcheck.RefIntPair

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2ecbdecf7318f401 soot_jimple_toolkits_annotation_nullcheck_RefIntPair

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_nullcheck_RefIntPair_H_
#define _JC_soot_jimple_toolkits_annotation_nullcheck_RefIntPair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_EquivalentValue$object;
struct _jc_soot_jimple_toolkits_annotation_nullcheck_BranchedRefVarsAnalysis$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$sub_refs	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$refs	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$nonrefs	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$object	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vmethods	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vtable	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vtype	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$method$_init$94c2e2150729b98f(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$object *, struct _jc_soot_EquivalentValue$object *, jint, struct _jc_soot_jimple_toolkits_annotation_nullcheck_BranchedRefVarsAnalysis$object *);

// Virtual methods
extern struct _jc_soot_EquivalentValue$object *_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$method$ref$4f5136ba09786e4c(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$object *);
extern jint _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$method$val$ed5187ba381d41f0(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$method_info$ref$4f5136ba09786e4c;
extern _jc_method _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$method_info$val$ed5187ba381d41f0;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vmethods {
	struct _jc_soot_EquivalentValue$object	*(*ref$4f5136ba09786e4c)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$object *);
	jint	(*val$ed5187ba381d41f0)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vmethods	soot_jimple_toolkits_annotation_nullcheck_RefIntPair;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$sub_refs {
	struct _jc_soot_EquivalentValue$object	*__5fref;
	struct _jc_soot_jimple_toolkits_annotation_nullcheck_BranchedRefVarsAnalysis$object	*brva;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$refs {
    _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$sub_refs	soot_jimple_toolkits_annotation_nullcheck_RefIntPair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$sub_nonrefs {
	jint	__5fval;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$sub_nonrefs	soot_jimple_toolkits_annotation_nullcheck_RefIntPair;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$object {
	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vtype _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_nullcheck_RefIntPair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_nullcheck_RefIntPair_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/nullcheck/RefIntPair.h <==
// public class soot.jimple.toolkits.annotation.nullcheck.RefIntPair

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2ecbdecf7318f401 soot_jimple_toolkits_annotation_nullcheck_RefIntPair

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_nullcheck_RefIntPair_H_
#define _JC_soot_jimple_toolkits_annotation_nullcheck_RefIntPair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_EquivalentValue$object;
struct _jc_soot_jimple_toolkits_annotation_nullcheck_BranchedRefVarsAnalysis$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$sub_refs	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$refs	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$nonrefs	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$object	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vmethods	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vtable	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vtype	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$method$_init$94c2e2150729b98f(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$object *, struct _jc_soot_EquivalentValue$object *, jint, struct _jc_soot_jimple_toolkits_annotation_nullcheck_BranchedRefVarsAnalysis$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_EquivalentValue$object *_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$method$ref$4f5136ba09786e4c(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$method$val$ed5187ba381d41f0(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$method_info$ref$4f5136ba09786e4c;
extern _jc_method _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$method_info$val$ed5187ba381d41f0;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vmethods {
	struct _jc_soot_EquivalentValue$object	*(*ref$4f5136ba09786e4c)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$object *) _JC_JCNI_ATTR;
	jint	(*val$ed5187ba381d41f0)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vmethods	soot_jimple_toolkits_annotation_nullcheck_RefIntPair;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$sub_refs {
	struct _jc_soot_EquivalentValue$object	*__5fref;
	struct _jc_soot_jimple_toolkits_annotation_nullcheck_BranchedRefVarsAnalysis$object	*brva;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$refs {
    _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$sub_refs	soot_jimple_toolkits_annotation_nullcheck_RefIntPair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$sub_nonrefs {
	jint	__5fval;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$sub_nonrefs	soot_jimple_toolkits_annotation_nullcheck_RefIntPair;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$object {
	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$vtype _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_nullcheck_RefIntPair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_nullcheck_RefIntPair$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_nullcheck_RefIntPair_H_ */
